@@ -2,16 +2,16 @@
 // Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This program is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -45,7 +45,7 @@ using namespace MediaInfoNameSpace;
 //---------------------------------------------------------------------------
 
 //****************************************************************************
-// Event to manage         
+// Event to manage
 //****************************************************************************
 
 void Log_0 (struct MediaInfo_Event_Log_0* Event, struct UserHandle_struct* UserHandler)
@@ -53,7 +53,7 @@ void Log_0 (struct MediaInfo_Event_Log_0* Event, struct UserHandle_struct* UserH
     String MessageString;
 
     if (Event->Type>=0xC0)
-        MessageString+=_T("E: ");
+        MessageString+=__T("E: ");
 
     #if defined(UNICODE) || defined (_UNICODE)
         MessageString+=Event->MessageStringU;
@@ -64,10 +64,10 @@ void Log_0 (struct MediaInfo_Event_Log_0* Event, struct UserHandle_struct* UserH
     //Special cases
     switch (Event->MessageCode)
     {
-        case 0xF1010101 : MessageString+=_T(" If you want to use such protocols, compile libcurl with SSL/SSH support"); break;
+        case 0xF1010101 : MessageString+=__T(" If you want to use such protocols, compile libcurl with SSL/SSH support"); break;
         case 0xF1010102 :
-        case 0xF1010103 : MessageString+=_T(" If you are in a secure environment, do \"ssh %YourServerName%\" in order to add the fingerprint to the known_hosts file. If you want to ignore security issues, use --Ssh_IgnoreSecurity option"); break;
-        case 0xF1010104 : MessageString+=_T(" If you want to ignore security issues, use --Ssl_IgnoreSecurity option."); break;
+        case 0xF1010103 : MessageString+=__T(" If you are in a secure environment, do \"ssh %YourServerName%\" in order to add the fingerprint to the known_hosts file. If you want to ignore security issues, use --Ssh_IgnoreSecurity option"); break;
+        case 0xF1010104 : MessageString+=__T(" If you want to ignore security issues, use --Ssl_IgnoreSecurity option."); break;
         default         : ;
     }
 
@@ -78,7 +78,7 @@ void Log_0 (struct MediaInfo_Event_Log_0* Event, struct UserHandle_struct* UserH
 }
 
 //****************************************************************************
-// The callback function                                                   
+// The callback function
 //****************************************************************************
 
 void __stdcall Event_CallBackFunction(unsigned char* Data_Content, size_t Data_Size, void* UserHandler_Void)
@@ -120,7 +120,7 @@ int main(int argc, char* argv_ansi[])
         _setmode(_fileno(stderr), _O_U8TEXT);
         CLI_Option_Bom=false;
     #endif
-    MediaInfo::Option_Static(_T("LineSeparator"), _T("\n")); //Using sdtout
+    MediaInfo::Option_Static(__T("LineSeparator"), __T("\n")); //Using sdtout
 
     //Configure MediaInfo core
     Core MI;
@@ -135,7 +135,7 @@ int main(int argc, char* argv_ansi[])
     {
         //First part of argument (before "=") should be case insensitive
         String Argument(argv[Pos]);
-        size_t Egal_Pos=Argument.find(_T('='));
+        size_t Egal_Pos=Argument.find(__T('='));
         if (Egal_Pos==string::npos)
             Egal_Pos=Argument.size();
         transform(Argument.begin(), Argument.begin()+Egal_Pos, Argument.begin(), (int(*)(int))tolower); //(int(*)(int)) is a patch for unix
@@ -164,7 +164,7 @@ int main(int argc, char* argv_ansi[])
 
     //Output, in a file if needed
     LogFile_Action(MI.Inform_Get());
-    
+
     return Files_Count?0:1;
 }
 //---------------------------------------------------------------------------
