@@ -2,16 +2,16 @@
 // Copyright (C) 2007-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This library is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // any later version.
 //
 // This library is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this library. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -57,7 +57,7 @@ size_t GUI_Main_Common_Core::FilesPos_Get()
 //---------------------------------------------------------------------------
 String GUI_Main_Common_Core::FileName_Get()
 {
-    return C->MI->Get(File_Pos, Stream_General, 0, _T("CompleteName")).c_str();
+    return C->MI->Get(File_Pos, Stream_General, 0, __T("CompleteName")).c_str();
 }
 
 //***************************************************************************
@@ -77,24 +77,24 @@ size_t GUI_Main_Common_Core::StreamsCount_Get(stream_t StreamKind)
 //---------------------------------------------------------------------------
 String GUI_Main_Common_Core::Summary_Get(stream_t StreamKind, size_t StreamPos)
 {
-    C->MI->Option(_T("Inform"), _T("Summary"));
-    return C->MI->Get(File_Pos, StreamKind, StreamPos, _T("Inform")).c_str();
+    C->MI->Option(__T("Inform"), __T("Summary"));
+    return C->MI->Get(File_Pos, StreamKind, StreamPos, __T("Inform")).c_str();
 }
 
 //---------------------------------------------------------------------------
 String GUI_Main_Common_Core::Inform_Get(stream_t StreamKind, size_t StreamPos)
 {
-    C->MI->Option(_T("Inform"), _T(""));
-    return C->MI->Get(File_Pos, StreamKind, StreamPos, _T("Inform")).c_str();
+    C->MI->Option(__T("Inform"), __T(""));
+    return C->MI->Get(File_Pos, StreamKind, StreamPos, __T("Inform")).c_str();
 }
 
 //---------------------------------------------------------------------------
 String GUI_Main_Common_Core::CodecID_Url_Get(stream_t StreamKind, size_t StreamPos)
 {
-    if (!C->MI->Get(File_Pos, StreamKind, StreamPos, _T("CodecID/Url")).empty())
-        return C->MI->Get(File_Pos, StreamKind, StreamPos, _T("CodecID/Url")).c_str();
+    if (!C->MI->Get(File_Pos, StreamKind, StreamPos, __T("CodecID/Url")).empty())
+        return C->MI->Get(File_Pos, StreamKind, StreamPos, __T("CodecID/Url")).c_str();
     else
-        return C->MI->Get(File_Pos, StreamKind, StreamPos, _T("Format/Url")).c_str();
+        return C->MI->Get(File_Pos, StreamKind, StreamPos, __T("Format/Url")).c_str();
 }
 
 
