@@ -2,16 +2,16 @@
 // Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This program is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -112,62 +112,62 @@ void __fastcall TPreferencesF::General_Output_SelChange(TObject *Sender)
 {
     if (General_Output_Sel->ItemIndex==0)
     {
-        Prefs->Config(_T("Output"))=_T("Basic");
+        Prefs->Config(__T("Output"))=__T("Basic");
         MainF->Page->ActivePage=MainF->Page_Easy;
         MainF->Page_Easy_FileChange(NULL);
         General_Output_More->Visible=false;
     }
     if (General_Output_Sel->ItemIndex==1)
     {
-        Prefs->Config(_T("Output"))=_T("Sheet");
+        Prefs->Config(__T("Output"))=__T("Sheet");
         MainF->Page->ActivePage=MainF->Page_Sheet;
         General_Output_More->Visible=true;
     }
     if (General_Output_Sel->ItemIndex==2)
     {
-        Prefs->Config(_T("Output"))=_T("Tree");
+        Prefs->Config(__T("Output"))=__T("Tree");
         MainF->Page->ActivePage=MainF->Page_Tree;
         General_Output_More->Visible=false;
     }
     if (General_Output_Sel->ItemIndex==3)
     {
-        Prefs->Config(_T("Output"))=_T("Text");
+        Prefs->Config(__T("Output"))=__T("Text");
         MainF->Page->ActivePage=MainF->Page_Tree;
         General_Output_More->Visible=false;
     }
     if (General_Output_Sel->ItemIndex==4)
     {
-        Prefs->Config(_T("Output"))=_T("HTML");
+        Prefs->Config(__T("Output"))=__T("HTML");
         MainF->Page->ActivePage=MainF->Page_HTML;
         General_Output_More->Visible=false;
     }
     if (General_Output_Sel->ItemIndex==5)
     {
-        Prefs->Config(_T("Output"))=_T("XML");
+        Prefs->Config(__T("Output"))=__T("XML");
         MainF->Page->ActivePage=MainF->Page_Custom;
         General_Output_More->Visible=false;
     }
     if (General_Output_Sel->ItemIndex==6)
     {
-        Prefs->Config(_T("Output"))=_T("MPEG-7");
+        Prefs->Config(__T("Output"))=__T("MPEG-7");
         MainF->Page->ActivePage=MainF->Page_Custom;
         General_Output_More->Visible=false;
     }
     if (General_Output_Sel->ItemIndex==7)
     {
-        Prefs->Config(_T("Output"))=_T("PBCore_1.2");
+        Prefs->Config(__T("Output"))=__T("PBCore_1.2");
         MainF->Page->ActivePage=MainF->Page_Custom;
         General_Output_More->Visible=false;
     }
     if (General_Output_Sel->ItemIndex==8)
     {
-        Prefs->Config(_T("Output"))=_T("reVTMD");
+        Prefs->Config(__T("Output"))=__T("reVTMD");
         MainF->Page->ActivePage=MainF->Page_Custom;
         General_Output_More->Visible=false;
     }
     if (General_Output_Sel->ItemIndex==9)
     {
-        Prefs->Config(_T("Output"))=_T("Custom");
+        Prefs->Config(__T("Output"))=__T("Custom");
         MainF->Page->ActivePage=MainF->Page_Custom;
         General_Output_More->Visible=true;
     }
@@ -200,7 +200,7 @@ void __fastcall TPreferencesF::Sheet_SelChange(TObject *Sender)
         Sheet_Delete->Enabled=true;
 
     //Save choice
-    Prefs->Config(_T("Sheet"))=GUI_Text(Sheet_Sel->Text);
+    Prefs->Config(__T("Sheet"))=GUI_Text(Sheet_Sel->Text);
 }
 
 //---------------------------------------------------------------------------
@@ -221,8 +221,8 @@ void __fastcall TPreferencesF::Sheet_EditClick(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TPreferencesF::Sheet_NewClick(TObject *Sender)
 {
-	UnicodeString S1=_T("New");
-    if (!InputQuery(_T("New sheet"), _T("Enter name of new sheet"), S1))
+    UnicodeString S1=__T("New");
+    if (!InputQuery(__T("New sheet"), __T("Enter name of new sheet"), S1))
         return;
 
     Prefs->Create(Prefs_Sheet, S1.c_str());
@@ -243,7 +243,7 @@ void __fastcall TPreferencesF::Custom_SelChange(TObject *Sender)
         Custom_Delete->Enabled=true;
 
     //Save choice
-    Prefs->Config(_T("Custom"))=GUI_Text(Custom_Sel->Text);
+    Prefs->Config(__T("Custom"))=GUI_Text(Custom_Sel->Text);
 }
 
 //---------------------------------------------------------------------------
@@ -274,10 +274,10 @@ void __fastcall TPreferencesF::CB_CheckUpdateClick(TObject *Sender)
     //Internet
     if (CB_CheckUpdate->Checked)
     {
-        Prefs->Config(_T("CheckUpdate"), 1)=_T("1");
+        Prefs->Config(__T("CheckUpdate"), 1)=__T("1");
     }
     else
-        Prefs->Config(_T("CheckUpdate"), 1)=_T("0");
+        Prefs->Config(__T("CheckUpdate"), 1)=__T("0");
 }
 
 //---------------------------------------------------------------------------
@@ -285,9 +285,9 @@ void __fastcall TPreferencesF::CB_InscrireShellClick(TObject *Sender)
 {
     //Shell extension
     if (CB_InscrireShell->Checked)
-        Prefs->Config(_T("ShellExtension"), 1)=_T("1");
+        Prefs->Config(__T("ShellExtension"), 1)=__T("1");
     else
-        Prefs->Config(_T("ShellExtension"), 1)=_T("0");
+        Prefs->Config(__T("ShellExtension"), 1)=__T("0");
 }
 
 //---------------------------------------------------------------------------
@@ -295,9 +295,9 @@ void __fastcall TPreferencesF::CB_InscrireShell_FolderClick(TObject *Sender)
 {
     //Shell extension
     if (CB_InscrireShell_Folder->Checked)
-        Prefs->Config(_T("ShellExtension_Folder"), 1)=_T("1");
+        Prefs->Config(__T("ShellExtension_Folder"), 1)=__T("1");
     else
-        Prefs->Config(_T("ShellExtension_Folder"), 1)=_T("0");
+        Prefs->Config(__T("ShellExtension_Folder"), 1)=__T("0");
 
 }
 
@@ -306,15 +306,15 @@ void __fastcall TPreferencesF::CB_InfoTipClick(TObject *Sender)
 {
     //ToolTip
     if (CB_InfoTip->Checked)
-        Prefs->Config(_T("ShellInfoTip"), 1)=_T("1");
+        Prefs->Config(__T("ShellInfoTip"), 1)=__T("1");
     else
-        Prefs->Config(_T("ShellInfoTip"), 1)=_T("0");
+        Prefs->Config(__T("ShellInfoTip"), 1)=__T("0");
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TPreferencesF::CB_ShowToolBarClick(TObject *Sender)
 {
-    Prefs->Config(_T("ShowToolBar"), 1)=CB_ShowToolBar->Checked?_T("1"):_T("0");
+    Prefs->Config(__T("ShowToolBar"), 1)=CB_ShowToolBar->Checked?__T("1"):__T("0");
     MainF->M_Options_ShowToolBar->Checked=CB_ShowToolBar->Checked;
     MainF->M_Options_ShowToolBarClick(Sender);
 }
@@ -322,7 +322,7 @@ void __fastcall TPreferencesF::CB_ShowToolBarClick(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TPreferencesF::CB_ShowMenuClick(TObject *Sender)
 {
-    Prefs->Config(_T("ShowMenu"), 1)=CB_ShowMenu->Checked?_T("1"):_T("0");
+    Prefs->Config(__T("ShowMenu"), 1)=CB_ShowMenu->Checked?__T("1"):__T("0");
     MainF->M_Options_ShowMenu->Checked=CB_ShowMenu->Checked;
     MainF->M_Options_ShowMenuClick(Sender);
 }
@@ -331,17 +331,17 @@ void __fastcall TPreferencesF::CB_ShowMenuClick(TObject *Sender)
 void __fastcall TPreferencesF::Advanced_CloseAllAutoClick(TObject *Sender)
 {
     if (Advanced_CloseAllAuto->Checked)
-        Prefs->Config(_T("CloseAllAuto"), 1)=_T("1");
+        Prefs->Config(__T("CloseAllAuto"), 1)=__T("1");
     else
-        Prefs->Config(_T("CloseAllAuto"), 1)=_T("0");
+        Prefs->Config(__T("CloseAllAuto"), 1)=__T("0");
     MainF->M_Options_CloseAllAuto->Checked=Advanced_CloseAllAuto->Checked;
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TPreferencesF::Language_NewClick(TObject *Sender)
 {
-	UnicodeString S1=_T("New");
-	if (!InputQuery(_T("New language"), _T("Enter name of new language"), S1))
+    UnicodeString S1=__T("New");
+    if (!InputQuery(__T("New language"), __T("Enter name of new language"), S1))
         return;
 
     Prefs->Create(Prefs_Language, S1.c_str());
@@ -364,8 +364,8 @@ void __fastcall TPreferencesF::Language_DeleteClick(TObject *Sender)
 //---------------------------------------------------------------------------
 void __fastcall TPreferencesF::Custom_NewClick(TObject *Sender)
 {
-	UnicodeString S1=_T("New");
-	if (!InputQuery(_T("New Output"), _T("Enter name of new Output"), S1))
+    UnicodeString S1=__T("New");
+    if (!InputQuery(__T("New Output"), __T("Enter name of new Output"), S1))
         return;
 
     Prefs->Create(Prefs_Custom, S1.c_str());
@@ -456,18 +456,18 @@ void __fastcall TPreferencesF::FormShow(TObject *Sender)
 void __fastcall TPreferencesF::Setup_GeneralShow(TObject *Sender)
 {
     ComboBox_Update(General_Language_Sel, Prefs_Language);
-    CB_CheckUpdate->Checked=Prefs->Config(_T("CheckUpdate")).To_int32s();
-    CB_InscrireShell->Checked=Prefs->Config(_T("ShellExtension")).To_int32s(); //Lecture Shell extension
-    CB_InscrireShell_Folder->Checked=Prefs->Config(_T("ShellExtension_Folder")).To_int32s(); //Lecture Shell extension
-    CB_InfoTip->Checked=Prefs->Config(_T("ShellInfoTip")).To_int32s(); //Lecture Shell extension
+    CB_CheckUpdate->Checked=Prefs->Config(__T("CheckUpdate")).To_int32s();
+    CB_InscrireShell->Checked=Prefs->Config(__T("ShellExtension")).To_int32s(); //Lecture Shell extension
+    CB_InscrireShell_Folder->Checked=Prefs->Config(__T("ShellExtension_Folder")).To_int32s(); //Lecture Shell extension
+    CB_InfoTip->Checked=Prefs->Config(__T("ShellInfoTip")).To_int32s(); //Lecture Shell extension
 }
 
 //---------------------------------------------------------------------------
 void __fastcall TPreferencesF::Setup_AdvancedShow(TObject *Sender)
 {
-    CB_ShowToolBar->Checked=Prefs->Config(_T("ShowToolBar")).To_int32s();
-    CB_ShowMenu->Checked=Prefs->Config(_T("ShowMenu")).To_int32s();
-    Advanced_CloseAllAuto->Checked=Prefs->Config(_T("CloseAllAuto")).To_int32s();
+    CB_ShowToolBar->Checked=Prefs->Config(__T("ShowToolBar")).To_int32s();
+    CB_ShowMenu->Checked=Prefs->Config(__T("ShowMenu")).To_int32s();
+    Advanced_CloseAllAuto->Checked=Prefs->Config(__T("CloseAllAuto")).To_int32s();
 }
 
 //---------------------------------------------------------------------------
@@ -493,71 +493,71 @@ void __fastcall TPreferencesF::GUI_Configure()
 
     //Translation
     //Title
-    Caption=Prefs->Translate(_T("Preferences")).c_str();
+    Caption=Prefs->Translate(__T("Preferences")).c_str();
     //Buttons
-    OK->Caption=Prefs->Translate(_T("OK")).c_str();
-    Cancel->Caption=Prefs->Translate(_T("Cancel")).c_str();
+    OK->Caption=Prefs->Translate(__T("OK")).c_str();
+    Cancel->Caption=Prefs->Translate(__T("Cancel")).c_str();
     //-Left panel
-    Tree->Items->Item[0]->Text=Prefs->Translate(_T("Setup")).c_str();
-    Tree->Items->Item[1]->Text=Prefs->Translate(_T("Advanced")).c_str();
-    Tree->Items->Item[2]->Text=Prefs->Translate(_T("Customize")).c_str();
-    Tree->Items->Item[3]->Text=Prefs->Translate(_T("Sheet")).c_str();
-    Tree->Items->Item[4]->Text=Prefs->Translate(_T("Tree & Text")).c_str();
-    Tree->Items->Item[5]->Text=Prefs->Translate(_T("Custom")).c_str();
-    Tree->Items->Item[6]->Text=Prefs->Translate(_T("Language")).c_str();
+    Tree->Items->Item[0]->Text=Prefs->Translate(__T("Setup")).c_str();
+    Tree->Items->Item[1]->Text=Prefs->Translate(__T("Advanced")).c_str();
+    Tree->Items->Item[2]->Text=Prefs->Translate(__T("Customize")).c_str();
+    Tree->Items->Item[3]->Text=Prefs->Translate(__T("Sheet")).c_str();
+    Tree->Items->Item[4]->Text=Prefs->Translate(__T("Tree & Text")).c_str();
+    Tree->Items->Item[5]->Text=Prefs->Translate(__T("Custom")).c_str();
+    Tree->Items->Item[6]->Text=Prefs->Translate(__T("Language")).c_str();
     //-General
-    General_Language_More->Caption=(Prefs->Translate(_T("More"))+_T("...")).c_str();
-    Langue_C->Caption=Prefs->Translate(_T("Language")).c_str();
-    Output_C->Caption=Prefs->Translate(_T("Output format")).c_str();
-    General_Output_More->Caption=(Prefs->Translate(_T("More"))+_T("...")).c_str();
-    CB_CheckUpdate->Caption=Prefs->Translate(_T("Newest version")).c_str();
+    General_Language_More->Caption=(Prefs->Translate(__T("More"))+__T("...")).c_str();
+    Langue_C->Caption=Prefs->Translate(__T("Language")).c_str();
+    Output_C->Caption=Prefs->Translate(__T("Output format")).c_str();
+    General_Output_More->Caption=(Prefs->Translate(__T("More"))+__T("...")).c_str();
+    CB_CheckUpdate->Caption=Prefs->Translate(__T("Newest version")).c_str();
     //--Special case : Output
     General_Output_Sel->Items->Clear();
-    General_Output_Sel->Items->Add(Prefs->Translate(_T("Basic")).c_str());
-    General_Output_Sel->Items->Add(Prefs->Translate(_T("Sheet")).c_str());
-    General_Output_Sel->Items->Add(Prefs->Translate(_T("Tree")).c_str());
-    General_Output_Sel->Items->Add(Prefs->Translate(_T("Text")).c_str());
-    General_Output_Sel->Items->Add(Prefs->Translate(_T("HTML")).c_str());
+    General_Output_Sel->Items->Add(Prefs->Translate(__T("Basic")).c_str());
+    General_Output_Sel->Items->Add(Prefs->Translate(__T("Sheet")).c_str());
+    General_Output_Sel->Items->Add(Prefs->Translate(__T("Tree")).c_str());
+    General_Output_Sel->Items->Add(Prefs->Translate(__T("Text")).c_str());
+    General_Output_Sel->Items->Add(Prefs->Translate(__T("HTML")).c_str());
     General_Output_Sel->Items->Add("XML");
     General_Output_Sel->Items->Add("MPEG-7");
     General_Output_Sel->Items->Add("PBCore_1.2");
     General_Output_Sel->Items->Add("reVTMD");
-    General_Output_Sel->Items->Add(Prefs->Translate(_T("Custom")).c_str());
-         if (Prefs->Config(_T("Output"))==_T("Basic"))      General_Output_Sel->ItemIndex=0;
-    else if (Prefs->Config(_T("Output"))==_T("Sheet"))      General_Output_Sel->ItemIndex=1;
-    else if (Prefs->Config(_T("Output"))==_T("Tree"))       General_Output_Sel->ItemIndex=2;
-    else if (Prefs->Config(_T("Output"))==_T("Text"))       General_Output_Sel->ItemIndex=3;
-    else if (Prefs->Config(_T("Output"))==_T("HTML"))       General_Output_Sel->ItemIndex=4;
-    else if (Prefs->Config(_T("Output"))==_T("XML"))        General_Output_Sel->ItemIndex=5;
-    else if (Prefs->Config(_T("Output"))==_T("MPEG-7"))     General_Output_Sel->ItemIndex=6;
-    else if (Prefs->Config(_T("Output"))==_T("PBCore_1.2")) General_Output_Sel->ItemIndex=7;
-    else if (Prefs->Config(_T("Output"))==_T("reVTMD"))     General_Output_Sel->ItemIndex=8;
-    else if (Prefs->Config(_T("Output"))==_T("Custom"))     General_Output_Sel->ItemIndex=9;
+    General_Output_Sel->Items->Add(Prefs->Translate(__T("Custom")).c_str());
+         if (Prefs->Config(__T("Output"))==__T("Basic"))      General_Output_Sel->ItemIndex=0;
+    else if (Prefs->Config(__T("Output"))==__T("Sheet"))      General_Output_Sel->ItemIndex=1;
+    else if (Prefs->Config(__T("Output"))==__T("Tree"))       General_Output_Sel->ItemIndex=2;
+    else if (Prefs->Config(__T("Output"))==__T("Text"))       General_Output_Sel->ItemIndex=3;
+    else if (Prefs->Config(__T("Output"))==__T("HTML"))       General_Output_Sel->ItemIndex=4;
+    else if (Prefs->Config(__T("Output"))==__T("XML"))        General_Output_Sel->ItemIndex=5;
+    else if (Prefs->Config(__T("Output"))==__T("MPEG-7"))     General_Output_Sel->ItemIndex=6;
+    else if (Prefs->Config(__T("Output"))==__T("PBCore_1.2")) General_Output_Sel->ItemIndex=7;
+    else if (Prefs->Config(__T("Output"))==__T("reVTMD"))     General_Output_Sel->ItemIndex=8;
+    else if (Prefs->Config(__T("Output"))==__T("Custom"))     General_Output_Sel->ItemIndex=9;
     //-Advanced
-    Setup_Advanced->Caption=Prefs->Translate(_T("Advanced")).c_str();
-    CB_InscrireShell->Caption=Prefs->Translate(_T("Shell extension")).c_str();
-    CB_InscrireShell_Folder->Caption=Prefs->Translate(_T("Shell extension, folder")).c_str();
-    CB_InfoTip->Caption=Prefs->Translate(_T("Shell InfoTip")).c_str();
-    CB_ShowToolBar->Caption=Prefs->Translate(_T("Show toolbar")).c_str();
-    CB_ShowMenu->Caption=Prefs->Translate(_T("Show menu")).c_str();
-    Advanced_CloseAllAuto->Caption=Prefs->Translate(_T("Close all before open")).c_str();
+    Setup_Advanced->Caption=Prefs->Translate(__T("Advanced")).c_str();
+    CB_InscrireShell->Caption=Prefs->Translate(__T("Shell extension")).c_str();
+    CB_InscrireShell_Folder->Caption=Prefs->Translate(__T("Shell extension, folder")).c_str();
+    CB_InfoTip->Caption=Prefs->Translate(__T("Shell InfoTip")).c_str();
+    CB_ShowToolBar->Caption=Prefs->Translate(__T("Show toolbar")).c_str();
+    CB_ShowMenu->Caption=Prefs->Translate(__T("Show menu")).c_str();
+    Advanced_CloseAllAuto->Caption=Prefs->Translate(__T("Close all before open")).c_str();
     //-Language
-    Language_Caption->Caption=Prefs->Translate(_T("Choose language")).c_str();
-    Language_Edit->Caption=(Prefs->Translate(_T("Edit"))+_T("...")).c_str();
-    Language_Delete->Caption=Prefs->Translate(_T("Delete")).c_str();
-    Language_New->Caption=(Prefs->Translate(_T("New"))+_T("...")).c_str();
+    Language_Caption->Caption=Prefs->Translate(__T("Choose language")).c_str();
+    Language_Edit->Caption=(Prefs->Translate(__T("Edit"))+__T("...")).c_str();
+    Language_Delete->Caption=Prefs->Translate(__T("Delete")).c_str();
+    Language_New->Caption=(Prefs->Translate(__T("New"))+__T("...")).c_str();
     //-Sheet
-    Sheet_Caption->Caption=Prefs->Translate(_T("Choose custom sheet")).c_str();
-    Sheet_Edit->Caption=(Prefs->Translate(_T("Edit"))+_T("...")).c_str();
-    Sheet_Delete->Caption=Prefs->Translate(_T("Delete")).c_str();
-    Sheet_New->Caption=(Prefs->Translate(_T("New"))+_T("...")).c_str();
+    Sheet_Caption->Caption=Prefs->Translate(__T("Choose custom sheet")).c_str();
+    Sheet_Edit->Caption=(Prefs->Translate(__T("Edit"))+__T("...")).c_str();
+    Sheet_Delete->Caption=Prefs->Translate(__T("Delete")).c_str();
+    Sheet_New->Caption=(Prefs->Translate(__T("New"))+__T("...")).c_str();
     //-Tree
-    Tree_NotYet->Caption=(Prefs->Translate(_T("Not yet"))+_T("...")).c_str();
+    Tree_NotYet->Caption=(Prefs->Translate(__T("Not yet"))+__T("...")).c_str();
     //-Custom
-    Custom_Caption->Caption=Prefs->Translate(_T("Choose custom text")).c_str();
-    Custom_Edit->Caption=(Prefs->Translate(_T("Edit"))+_T("...")).c_str();
-    Custom_Delete->Caption=Prefs->Translate(_T("Delete")).c_str();
-    Custom_New->Caption=(Prefs->Translate(_T("New"))+_T("...")).c_str();
+    Custom_Caption->Caption=Prefs->Translate(__T("Choose custom text")).c_str();
+    Custom_Edit->Caption=(Prefs->Translate(__T("Edit"))+__T("...")).c_str();
+    Custom_Delete->Caption=Prefs->Translate(__T("Delete")).c_str();
+    Custom_New->Caption=(Prefs->Translate(__T("New"))+__T("...")).c_str();
 }
 
 //***************************************************************************
