@@ -2,16 +2,16 @@
 // Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This program is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -45,20 +45,20 @@ bool FileDrop::OnDropFiles(wxCoord, wxCoord, const wxArrayString& FileNames)
         wxArrayString FileNames2;
         for (size_t Pos=0; Pos<FileNames.size(); Pos++)
         {
-	        if (wxFile::Exists(FileNames[Pos]) || wxDir::Exists(FileNames[Pos]))
-		        FileNames2.Add(FileNames[Pos]);
-	        else
-	        {
-		        wxString Temp(FileNames[Pos]);
-		        std::string Temp2;
-		        for (size_t Temp_Pos=0; Temp_Pos<Temp.size(); Temp_Pos++)
-			        Temp2.append(1, (char)Temp[Temp_Pos]);
-		        wxString Temp3(Temp2.c_str(), wxConvLocal);
-	            if (wxFile::Exists(Temp3) || wxDir::Exists(Temp3))
-		            FileNames2.Add(Temp3);
-	            else
-		            FileNames2.Add(FileNames[Pos]);
-	        }
+            if (wxFile::Exists(FileNames[Pos]) || wxDir::Exists(FileNames[Pos]))
+                FileNames2.Add(FileNames[Pos]);
+            else
+            {
+                wxString Temp(FileNames[Pos]);
+                std::string Temp2;
+                for (size_t Temp_Pos=0; Temp_Pos<Temp.size(); Temp_Pos++)
+                    Temp2.append(1, (char)Temp[Temp_Pos]);
+                wxString Temp3(Temp2.c_str(), wxConvLocal);
+                if (wxFile::Exists(Temp3) || wxDir::Exists(Temp3))
+                    FileNames2.Add(Temp3);
+                else
+                    FileNames2.Add(FileNames[Pos]);
+            }
         }
     #endif //!defined(__WXMSW__)
 
@@ -75,7 +75,7 @@ bool FileDrop::OnDropFiles(wxCoord, wxCoord, const wxArrayString& FileNames)
     ((GUI_Main*)C->GUI_Main_Handler)->View_Refresh();
     if (((GUI_Main*)C->GUI_Main_Handler)->GetStatusBar()==NULL)
         ((GUI_Main*)C->GUI_Main_Handler)->CreateStatusBar();
-    ((GUI_Main*)C->GUI_Main_Handler)->GetStatusBar()->SetLabel(Span.Format(_T("%Ss %lms")));
+    ((GUI_Main*)C->GUI_Main_Handler)->GetStatusBar()->SetLabel(Span.Format(__T("%Ss %lms")));
     return true;
 }
 #endif //wxUSE_DRAG_AND_DROP
