@@ -2,16 +2,16 @@
 // Copyright (C) 2002-2012 MediaArea.net SARL, Info@MediaArea.net
 //
 // This program is free software: you can redistribute it and/or modify it
-// under the terms of the GNU Lesser General Public License as published by
-// the Free Software Foundation, either version 3 of the License, or
+// under the terms of the GNU Library General Public License as published by
+// the Free Software Foundation, either version 2 of the License, or
 // (at your option) any later version.
 //
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-// GNU Lesser General Public License for more details.
+// GNU Library General Public License for more details.
 //
-// You should have received a copy of the GNU Lesser General Public License
+// You should have received a copy of the GNU Library General Public License
 // along with this program. If not, see <http://www.gnu.org/licenses/>.
 //
 //+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
@@ -66,9 +66,9 @@ void GUI_Main_HTML::GUI_Refresh()
 {
     std::string Temp(wxConvUTF8.cWX2MB(C->Inform_Get().c_str()));
     wxFileSystem::AddHandler(new wxMemoryFSHandler);
-    wxMemoryFSHandler::AddFile(_T("index.html"), Temp.c_str(), Temp.size());
-    LoadPage(_T("memory:index.html"));
-    wxMemoryFSHandler::RemoveFile(_T("index.html"));
+    wxMemoryFSHandler::AddFile(__T("index.html"), Temp.c_str(), Temp.size());
+    LoadPage(__T("memory:index.html"));
+    wxMemoryFSHandler::RemoveFile(__T("index.html"));
 }
 
 void GUI_Main_HTML::GUI_Resize()
